ColumnInfo class

Constructors

ColumnInfo({int? notnull, String? name, int? pk, String? type, int? cid})
ColumnInfo.fromJson(Map json)

Properties

cid ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
notnull ↔ int?
getter/setter pair
pk ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toBean(Map json) → ColumnInfo