TableInfo class

查询获取到的表信息

Constructors

TableInfo({String? name, String? tblName, int? rootPage, String? type, String? sql, List<ColumnInfo>? columns})
TableInfo.fromJson(Map json)

Properties

columns ↔ List<ColumnInfo>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
rootPage ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql ↔ String?
getter/setter pair
tblName ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toBean(Map json) → TableInfo